EmailTemplateType enum
Values
- verification → const EmailTemplateType
-
const EmailTemplateType(value: 'verification') - magicSession → const EmailTemplateType
-
const EmailTemplateType(value: 'magicSession') - recovery → const EmailTemplateType
-
const EmailTemplateType(value: 'recovery') - invitation → const EmailTemplateType
-
const EmailTemplateType(value: 'invitation') - mfaChallenge → const EmailTemplateType
-
const EmailTemplateType(value: 'mfaChallenge') - sessionAlert → const EmailTemplateType
-
const EmailTemplateType(value: 'sessionAlert') - otpSession → const EmailTemplateType
-
const EmailTemplateType(value: 'otpSession')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EmailTemplateType> - A constant List of the values in this enum, in order of their declaration.