Framework enum
Values
- analog → const Framework
-
const Framework(value: "analog") - angular → const Framework
-
const Framework(value: "angular") - nextjs → const Framework
-
const Framework(value: "nextjs") - react → const Framework
-
const Framework(value: "react") - nuxt → const Framework
-
const Framework(value: "nuxt") - vue → const Framework
-
const Framework(value: "vue") - sveltekit → const Framework
-
const Framework(value: "sveltekit") - astro → const Framework
-
const Framework(value: "astro") - tanstackStart → const Framework
-
const Framework(value: "tanstack-start") - remix → const Framework
-
const Framework(value: "remix") - lynx → const Framework
-
const Framework(value: "lynx") - flutter → const Framework
-
const Framework(value: "flutter") - reactNative → const Framework
-
const Framework(value: "react-native") - vite → const Framework
-
const Framework(value: "vite") - other → const Framework
-
const Framework(value: "other")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited