ProjectEmailTemplateId enum

Inheritance
Available extensions

Values

verification → const ProjectEmailTemplateId
const ProjectEmailTemplateId(value: 'verification')
magicSession → const ProjectEmailTemplateId
const ProjectEmailTemplateId(value: 'magicSession')
recovery → const ProjectEmailTemplateId
const ProjectEmailTemplateId(value: 'recovery')
invitation → const ProjectEmailTemplateId
const ProjectEmailTemplateId(value: 'invitation')
mfaChallenge → const ProjectEmailTemplateId
const ProjectEmailTemplateId(value: 'mfaChallenge')
sessionAlert → const ProjectEmailTemplateId
const ProjectEmailTemplateId(value: 'sessionAlert')
otpSession → const ProjectEmailTemplateId
const ProjectEmailTemplateId(value: 'otpSession')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProjectEmailTemplateId>
A constant List of the values in this enum, in order of their declaration.