ProjectKeyScopes enum

Inheritance
Available extensions

Values

projectRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "project.read")
projectWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "project.write")
usageRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "usage.read")
keysRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "keys.read")
keysWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "keys.write")
platformsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "platforms.read")
platformsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "platforms.write")
mocksRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "mocks.read")
mocksWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "mocks.write")
policiesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "policies.read")
policiesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "policies.write")
projectPoliciesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "project.policies.read")
projectPoliciesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "project.policies.write")
projectOauth2Read → const ProjectKeyScopes
const ProjectKeyScopes(value: "project.oauth2.read")
projectOauth2Write → const ProjectKeyScopes
const ProjectKeyScopes(value: "project.oauth2.write")
templatesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "templates.read")
templatesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "templates.write")
stagesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "stages.read")
stagesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "stages.write")
usersRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "users.read")
usersWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "users.write")
sessionsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "sessions.read")
sessionsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "sessions.write")
teamsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "teams.read")
teamsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "teams.write")
databasesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "databases.read")
databasesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "databases.write")
tablesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "tables.read")
tablesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "tables.write")
columnsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "columns.read")
columnsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "columns.write")
indexesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "indexes.read")
indexesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "indexes.write")
rowsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "rows.read")
rowsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "rows.write")
embeddingsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "embeddings.write")
collectionsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "collections.read")
collectionsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "collections.write")
attributesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "attributes.read")
attributesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "attributes.write")
documentsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "documents.read")
documentsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "documents.write")
documentsdbRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.read")
documentsdbWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.write")
documentsdbCollectionsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.collections.read")
documentsdbCollectionsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.collections.write")
documentsdbDocumentsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.documents.read")
documentsdbDocumentsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.documents.write")
documentsdbIndexesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.indexes.read")
documentsdbIndexesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "documentsdb.indexes.write")
vectorsdbRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.read")
vectorsdbWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.write")
vectorsdbCollectionsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.collections.read")
vectorsdbCollectionsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.collections.write")
vectorsdbDocumentsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.documents.read")
vectorsdbDocumentsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.documents.write")
vectorsdbIndexesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.indexes.read")
vectorsdbIndexesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "vectorsdb.indexes.write")
bucketsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "buckets.read")
bucketsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "buckets.write")
filesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "files.read")
filesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "files.write")
tokensRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "tokens.read")
tokensWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "tokens.write")
functionsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "functions.read")
functionsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "functions.write")
executionsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "executions.read")
executionsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "executions.write")
executionRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "execution.read")
executionWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "execution.write")
sitesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "sites.read")
sitesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "sites.write")
logRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "log.read")
logWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "log.write")
providersRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "providers.read")
providersWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "providers.write")
topicsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "topics.read")
topicsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "topics.write")
subscribersRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "subscribers.read")
subscribersWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "subscribers.write")
targetsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "targets.read")
targetsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "targets.write")
messagesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "messages.read")
messagesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "messages.write")
rulesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "rules.read")
rulesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "rules.write")
webhooksRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "webhooks.read")
webhooksWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "webhooks.write")
localeRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "locale.read")
avatarsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "avatars.read")
healthRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "health.read")
assistantRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "assistant.read")
migrationsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "migrations.read")
migrationsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "migrations.write")
schedulesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "schedules.read")
schedulesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "schedules.write")
vcsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "vcs.read")
vcsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "vcs.write")
insightsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "insights.read")
insightsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "insights.write")
reportsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "reports.read")
reportsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "reports.write")
presencesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "presences.read")
presencesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "presences.write")
backupsPoliciesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "backups.policies.read")
backupsPoliciesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "backups.policies.write")
archivesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "archives.read")
archivesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "archives.write")
restorationsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "restorations.read")
restorationsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "restorations.write")
domainsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "domains.read")
domainsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "domains.write")
wafRulesRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "wafRules.read")
wafRulesWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "wafRules.write")
eventsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "events.read")
proxyInvalidationsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "proxy.invalidations.write")
appsRead → const ProjectKeyScopes
const ProjectKeyScopes(value: "apps.read")
appsWrite → const ProjectKeyScopes
const ProjectKeyScopes(value: "apps.write")
oauth2Read → const ProjectKeyScopes
const ProjectKeyScopes(value: "oauth2.read")
oauth2Write → const ProjectKeyScopes
const ProjectKeyScopes(value: "oauth2.write")
oauth2Introspect → const ProjectKeyScopes
const ProjectKeyScopes(value: "oauth2.introspect")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProjectKeyScopes>
A constant List of the values in this enum, in order of their declaration.