ProjectPolicyId enum

Inheritance
Available extensions

Values

passwordDictionary → const ProjectPolicyId
const ProjectPolicyId(value: "password-dictionary")
passwordHistory → const ProjectPolicyId
const ProjectPolicyId(value: "password-history")
passwordStrength → const ProjectPolicyId
const ProjectPolicyId(value: "password-strength")
passwordPersonalData → const ProjectPolicyId
const ProjectPolicyId(value: "password-personal-data")
sessionAlert → const ProjectPolicyId
const ProjectPolicyId(value: "session-alert")
sessionDuration → const ProjectPolicyId
const ProjectPolicyId(value: "session-duration")
sessionInvalidation → const ProjectPolicyId
const ProjectPolicyId(value: "session-invalidation")
sessionLimit → const ProjectPolicyId
const ProjectPolicyId(value: "session-limit")
userLimit → const ProjectPolicyId
const ProjectPolicyId(value: "user-limit")
membershipPrivacy → const ProjectPolicyId
const ProjectPolicyId(value: "membership-privacy")
mfaFactors → const ProjectPolicyId
const ProjectPolicyId(value: "mfa-factors")
denyAliasedEmail → const ProjectPolicyId
const ProjectPolicyId(value: "deny-aliased-email")
denyDisposableEmail → const ProjectPolicyId
const ProjectPolicyId(value: "deny-disposable-email")
denyFreeEmail → const ProjectPolicyId
const ProjectPolicyId(value: "deny-free-email")
denyCorporateEmail → const ProjectPolicyId
const ProjectPolicyId(value: "deny-corporate-email")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProjectPolicyId>
A constant List of the values in this enum, in order of their declaration.