Runtime enum

Inheritance
Available extensions

Values

node145 → const Runtime
const Runtime(value: "node-14.5")
node160 → const Runtime
const Runtime(value: "node-16.0")
node180 → const Runtime
const Runtime(value: "node-18.0")
node190 → const Runtime
const Runtime(value: "node-19.0")
node200 → const Runtime
const Runtime(value: "node-20.0")
node210 → const Runtime
const Runtime(value: "node-21.0")
node22 → const Runtime
const Runtime(value: "node-22")
node23 → const Runtime
const Runtime(value: "node-23")
node24 → const Runtime
const Runtime(value: "node-24")
node25 → const Runtime
const Runtime(value: "node-25")
node26 → const Runtime
const Runtime(value: "node-26")
php80 → const Runtime
const Runtime(value: "php-8.0")
php81 → const Runtime
const Runtime(value: "php-8.1")
php82 → const Runtime
const Runtime(value: "php-8.2")
php83 → const Runtime
const Runtime(value: "php-8.3")
php84 → const Runtime
const Runtime(value: "php-8.4")
ruby30 → const Runtime
const Runtime(value: "ruby-3.0")
ruby31 → const Runtime
const Runtime(value: "ruby-3.1")
ruby32 → const Runtime
const Runtime(value: "ruby-3.2")
ruby33 → const Runtime
const Runtime(value: "ruby-3.3")
ruby34 → const Runtime
const Runtime(value: "ruby-3.4")
ruby40 → const Runtime
const Runtime(value: "ruby-4.0")
python38 → const Runtime
const Runtime(value: "python-3.8")
python39 → const Runtime
const Runtime(value: "python-3.9")
python310 → const Runtime
const Runtime(value: "python-3.10")
python311 → const Runtime
const Runtime(value: "python-3.11")
python312 → const Runtime
const Runtime(value: "python-3.12")
python313 → const Runtime
const Runtime(value: "python-3.13")
python314 → const Runtime
const Runtime(value: "python-3.14")
pythonMl311 → const Runtime
const Runtime(value: "python-ml-3.11")
pythonMl312 → const Runtime
const Runtime(value: "python-ml-3.12")
pythonMl313 → const Runtime
const Runtime(value: "python-ml-3.13")
deno140 → const Runtime
const Runtime(value: "deno-1.40")
deno146 → const Runtime
const Runtime(value: "deno-1.46")
deno20 → const Runtime
const Runtime(value: "deno-2.0")
deno25 → const Runtime
const Runtime(value: "deno-2.5")
deno26 → const Runtime
const Runtime(value: "deno-2.6")
dart215 → const Runtime
const Runtime(value: "dart-2.15")
dart216 → const Runtime
const Runtime(value: "dart-2.16")
dart217 → const Runtime
const Runtime(value: "dart-2.17")
dart218 → const Runtime
const Runtime(value: "dart-2.18")
dart219 → const Runtime
const Runtime(value: "dart-2.19")
dart30 → const Runtime
const Runtime(value: "dart-3.0")
dart31 → const Runtime
const Runtime(value: "dart-3.1")
dart33 → const Runtime
const Runtime(value: "dart-3.3")
dart35 → const Runtime
const Runtime(value: "dart-3.5")
dart38 → const Runtime
const Runtime(value: "dart-3.8")
dart39 → const Runtime
const Runtime(value: "dart-3.9")
dart310 → const Runtime
const Runtime(value: "dart-3.10")
dart311 → const Runtime
const Runtime(value: "dart-3.11")
dart312 → const Runtime
const Runtime(value: "dart-3.12")
dotnet60 → const Runtime
const Runtime(value: "dotnet-6.0")
dotnet70 → const Runtime
const Runtime(value: "dotnet-7.0")
dotnet80 → const Runtime
const Runtime(value: "dotnet-8.0")
dotnet10 → const Runtime
const Runtime(value: "dotnet-10")
java80 → const Runtime
const Runtime(value: "java-8.0")
java110 → const Runtime
const Runtime(value: "java-11.0")
java170 → const Runtime
const Runtime(value: "java-17.0")
java180 → const Runtime
const Runtime(value: "java-18.0")
java210 → const Runtime
const Runtime(value: "java-21.0")
java22 → const Runtime
const Runtime(value: "java-22")
java25 → const Runtime
const Runtime(value: "java-25")
swift55 → const Runtime
const Runtime(value: "swift-5.5")
swift58 → const Runtime
const Runtime(value: "swift-5.8")
swift59 → const Runtime
const Runtime(value: "swift-5.9")
swift510 → const Runtime
const Runtime(value: "swift-5.10")
swift62 → const Runtime
const Runtime(value: "swift-6.2")
kotlin16 → const Runtime
const Runtime(value: "kotlin-1.6")
kotlin18 → const Runtime
const Runtime(value: "kotlin-1.8")
kotlin19 → const Runtime
const Runtime(value: "kotlin-1.9")
kotlin20 → const Runtime
const Runtime(value: "kotlin-2.0")
kotlin23 → const Runtime
const Runtime(value: "kotlin-2.3")
cpp17 → const Runtime
const Runtime(value: "cpp-17")
cpp20 → const Runtime
const Runtime(value: "cpp-20")
bun10 → const Runtime
const Runtime(value: "bun-1.0")
bun11 → const Runtime
const Runtime(value: "bun-1.1")
bun12 → const Runtime
const Runtime(value: "bun-1.2")
bun13 → const Runtime
const Runtime(value: "bun-1.3")
bun14 → const Runtime
const Runtime(value: "bun-1.4")
go123 → const Runtime
const Runtime(value: "go-1.23")
go124 → const Runtime
const Runtime(value: "go-1.24")
go125 → const Runtime
const Runtime(value: "go-1.25")
go126 → const Runtime
const Runtime(value: "go-1.26")
rust183 → const Runtime
const Runtime(value: "rust-1.83")
static1 → const Runtime
const Runtime(value: "static-1")
flutter324 → const Runtime
const Runtime(value: "flutter-3.24")
flutter327 → const Runtime
const Runtime(value: "flutter-3.27")
flutter329 → const Runtime
const Runtime(value: "flutter-3.29")
flutter332 → const Runtime
const Runtime(value: "flutter-3.32")
flutter335 → const Runtime
const Runtime(value: "flutter-3.35")
flutter338 → const Runtime
const Runtime(value: "flutter-3.38")
flutter341 → const Runtime
const Runtime(value: "flutter-3.41")
flutter344 → const Runtime
const Runtime(value: "flutter-3.44")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Runtime>
A constant List of the values in this enum, in order of their declaration.