teamId property
ID of team that owns the application, if owned by team. Otherwise, user ID will be used.
Implementation
final String teamId;
ID of team that owns the application, if owned by team. Otherwise, user ID will be used.
final String teamId;