type property
OAuth2 client type. public for SPAs, mobile, and native apps that cannot keep a client secret (PKCE required); confidential for server-side clients that authenticate with a client secret.
Implementation
final String type;
OAuth2 client type. public for SPAs, mobile, and native apps that cannot keep a client secret (PKCE required); confidential for server-side clients that authenticate with a client secret.
final String type;