userId property
ID of user who owns the application, if owned by user. Otherwise, team ID will be used.
Implementation
final String userId;
ID of user who owns the application, if owned by user. Otherwise, team ID will be used.
final String userId;