AppInstallation class

AppInstallation

Implemented types

Constructors

AppInstallation({required String $id, required String $createdAt, required String $updatedAt, required String appId, required String teamId, required List<String> scopes, required Map<String, dynamic> authorizationDetails, required String createdById, required String createdByName, String? lastAccessedAt})
AppInstallation.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Installation creation time in ISO 8601 format.
final
$id String
Installation ID.
final
$updatedAt String
Installation update time in ISO 8601 format.
final
appId String
ID of the installed application.
final
authorizationDetails Map<String, dynamic>
Authorization details granted to the application. Rich authorization request (RFC 9396) style entries; the Appwrite Console stores authorized project IDs here.
final
createdById String
ID of the user who created the installation.
final
createdByName String
Name of the user who created the installation.
final
hashCode int
The hash code for this object.
no setterinherited
lastAccessedAt String?
Time an access token was last issued for the installation in ISO 8601 format. Null if never used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
Scopes granted to the application. Snapshot of the application's installation scopes taken when the installation was created or last updated.
final
teamId String
ID of the team the application is installed on.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited