AppKey class

AppKey

Implemented types

Constructors

AppKey({required String $id, required String $createdAt, required String $updatedAt, required String appId, required String secret, required String hint, required String createdById, required String createdByName, String? lastAccessedAt})
AppKey.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
App key creation time in ISO 8601 format.
final
$id String
App key ID.
final
$updatedAt String
App key update time in ISO 8601 format.
final
appId String
Application ID this app key belongs to.
final
createdById String
ID of the user who created the app key.
final
createdByName String
Name of the user who created the app key.
final
hashCode int
The hash code for this object.
no setterinherited
hint String
Last few characters of the app key secret, used to help identify it.
final
lastAccessedAt String?
Time the app key was last used for authentication in ISO 8601 format. Null if never used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
App key secret.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited