lastAccessedAt property
Time the app key was last used for authentication in ISO 8601 format. Null if never used.
Implementation
final String? lastAccessedAt;
Time the app key was last used for authentication in ISO 8601 format. Null if never used.
final String? lastAccessedAt;