deprecated property
Whether the scope is deprecated. Deprecated scopes can still be requested but should not be offered for new grants.
Implementation
final bool deprecated;
Whether the scope is deprecated. Deprecated scopes can still be requested but should not be offered for new grants.
final bool deprecated;