secret property
Always empty. The application client secret is returned only once, in the response of the createSecret method.
Implementation
final String secret;
Always empty. The application client secret is returned only once, in the response of the createSecret method.
final String secret;