AppSecretPlaintext class

AppSecretPlaintext

Implemented types

Constructors

AppSecretPlaintext({required String $id, required String $createdAt, required String $updatedAt, required String appId, required String secret, required String hint, required String createdById, required String createdByName, String? lastAccessedAt})
AppSecretPlaintext.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Secret creation time in ISO 8601 format.
final
$id String
Secret ID.
final
$updatedAt String
Secret update time in ISO 8601 format.
final
appId String
Application ID this secret belongs to.
final
createdById String
ID of the user who created the secret.
final
createdByName String
Name of the user who created the secret.
final
hashCode int
The hash code for this object.
no setterinherited
hint String
Last few characters of the client secret, used to help identify it.
final
lastAccessedAt String?
Time the secret was last used for authentication in ISO 8601 format. Null if never used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
Application client secret. Returned only when the secret is created; subsequent reads always return an empty value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited