AppsList class

Apps list

Implemented types

Constructors

AppsList({required int total, required List<App> apps})
AppsList.fromMap(Map<String, dynamic> map)
factory

Properties

apps List<App>
List of apps.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of apps that matched your query.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited