BillingPlanAddon class

Addon

Implemented types

Constructors

BillingPlanAddon({BillingPlanAddonDetails? seats, BillingPlanAddonDetails? projects})
BillingPlanAddon.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
projects BillingPlanAddonDetails?
Addon projects
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seats BillingPlanAddonDetails?
Addon seats
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited