BillingPlanDedicatedDatabaseLimits class

dedicatedDatabaseLimits

Implemented types

Constructors

BillingPlanDedicatedDatabaseLimits({int? minCpu, int? maxCpu, int? minMemoryMb, int? maxMemoryMb, int? minStorageGb, int? maxStorageGb, int? maxReplicas, int? maxConnections, int? maxIpAllowlistSize, int? maxExtensions, int? maxBackupRetentionDays, int? maxPitrRetentionDays, int? maxSqlApiMaxRows, int? maxSqlApiMaxBytes, int? maxSqlApiTimeoutSeconds, int? maxSqlApiAllowedStatements, List<String>? allowedSqlStatements, List<String>? allowedStorageClasses, List<String>? allowedSyncModes})
BillingPlanDedicatedDatabaseLimits.fromMap(Map<String, dynamic> map)
factory

Properties

allowedSqlStatements List<String>?
SQL statement types permitted through the SQL API.
final
allowedStorageClasses List<String>?
Storage classes available for dedicated databases.
final
allowedSyncModes List<String>?
Replica synchronization modes available for dedicated databases.
final
hashCode int
The hash code for this object.
no setterinherited
maxBackupRetentionDays int?
Maximum number of days a backup can be retained.
final
maxConnections int?
Maximum number of client connections.
final
maxCpu int?
Maximum CPU allocation in millicores.
final
maxExtensions int?
Maximum number of database extensions that can be enabled.
final
maxIpAllowlistSize int?
Maximum number of entries allowed in the IP allowlist.
final
maxMemoryMb int?
Maximum memory allocation in megabytes.
final
maxPitrRetentionDays int?
Maximum number of days of point-in-time recovery data that can be retained.
final
maxReplicas int?
Maximum number of high-availability replicas per dedicated database.
final
maxSqlApiAllowedStatements int?
Maximum number of SQL statement types that can be permitted through the SQL API.
final
maxSqlApiMaxBytes int?
Maximum response size in bytes for a single SQL API query.
final
maxSqlApiMaxRows int?
Maximum number of rows a single SQL API query can return.
final
maxSqlApiTimeoutSeconds int?
Maximum execution time in seconds for a single SQL API query.
final
maxStorageGb int?
Maximum storage allocation in gigabytes.
final
minCpu int?
Minimum CPU allocation in millicores.
final
minMemoryMb int?
Minimum memory allocation in megabytes.
final
minStorageGb int?
Minimum storage allocation in gigabytes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited