maxSqlApiAllowedStatements property
Maximum number of SQL statement types that can be permitted through the SQL API.
Implementation
final int? maxSqlApiAllowedStatements;
Maximum number of SQL statement types that can be permitted through the SQL API.
final int? maxSqlApiAllowedStatements;