BillingPlanLimits class
PlanLimits
- Implemented types
Constructors
- BillingPlanLimits({int? credits, int? dailyCredits})
-
BillingPlanLimits.fromMap(Map<
String, dynamic> map) -
factory
Properties
- credits → int?
-
Credits limit per billing cycle
final
- dailyCredits → int?
-
Daily credits limit (if applicable)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited