BillingPlanSupportedAddons class

BillingPlanSupportedAddons

Implemented types

Constructors

BillingPlanSupportedAddons({required bool baa, required bool premiumGeoDB, required bool premiumGeoDBOrg})
BillingPlanSupportedAddons.fromMap(Map<String, dynamic> map)
factory

Properties

baa bool
Whether the plan supports BAA (Business Associate Agreement) addon
final
hashCode int
The hash code for this object.
no setterinherited
premiumGeoDB bool
Whether the plan supports Premium Geo DB addon (project-level)
final
premiumGeoDBOrg bool
Whether the plan supports Premium Geo DB addon (organization-level)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited