expiredAt property
Block expiration date in ISO 8601 format. Can be null if the block does not expire.
Implementation
final String? expiredAt;
Block expiration date in ISO 8601 format. Can be null if the block does not expire.
final String? expiredAt;