containerStatus property
Container status of the dedicated backing: active or inactive. Null when the database has no dedicated backing or the runtime has not reported one.
Implementation
final String? containerStatus;
Container status of the dedicated backing: active or inactive. Null when the database has no dedicated backing or the runtime has not reported one.
final String? containerStatus;