error property
Error message when the dedicated backing failed. Null when the database has no dedicated backing or has not failed.
Implementation
final String? error;
Error message when the dedicated backing failed. Null when the database has no dedicated backing or has not failed.
final String? error;