DatabaseStatus class

Status

Implemented types

Constructors

DatabaseStatus({required String health, required bool ready, required String engine, required String version, required int uptime, required DatabaseStatusConnections connections, required List<DatabaseStatusReplica> replicas, required List<DatabaseStatusVolume> volumes})
DatabaseStatus.fromMap(Map<String, dynamic> map)
factory

Properties

connections DatabaseStatusConnections
Connection statistics.
final
engine String
Database engine: postgresql, mysql, mariadb, or mongodb.
final
hashCode int
The hash code for this object.
no setterinherited
health String
Overall health status: healthy, degraded, or unhealthy.
final
ready bool
Whether the database is ready to accept connections.
final
replicas List<DatabaseStatusReplica>
List of database replicas and their status.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uptime int
Database uptime in seconds.
final
version String
Database engine version.
final
volumes List<DatabaseStatusVolume>
Storage volume information.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited