effectiveSyncMode property
Replication sync mode the primary is actually enforcing. Null when high availability is disabled or the state could not be read.
Implementation
final String? effectiveSyncMode;
Replication sync mode the primary is actually enforcing. Null when high availability is disabled or the state could not be read.
final String? effectiveSyncMode;