health property
Overall health status: healthy, degraded, unhealthy, or unknown when nothing could be measured.
Implementation
final String health;
Overall health status: healthy, degraded, unhealthy, or unknown when nothing could be measured.
final String health;