syncAcknowledgements property
Number of standby acknowledgements the primary waits for before a write is committed.
Implementation
final int syncAcknowledgements;
Number of standby acknowledgements the primary waits for before a write is committed.
final int syncAcknowledgements;