syncStandbyCount property
Number of standbys registered with the primary for synchronous replication.
Implementation
final int syncStandbyCount;
Number of standbys registered with the primary for synchronous replication.
final int syncStandbyCount;