syncStateConfirmed property
Whether the reported sync state was read from the engine. When false the state could not be confirmed and the other sync fields carry no reading.
Implementation
final bool syncStateConfirmed;
Whether the reported sync state was read from the engine. When false the state could not be confirmed and the other sync fields carry no reading.
final bool syncStateConfirmed;