DatabaseStatusConnections class

Connections

Implemented types

Constructors

DatabaseStatusConnections({required int current, required int max})
DatabaseStatusConnections.fromMap(Map<String, dynamic> map)
factory

Properties

current int
Current number of active connections.
final
hashCode int
The hash code for this object.
no setterinherited
max int
Maximum allowed connections.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited