index property
Member index within the database. Read role for which member accepts writes: a failover moves the primary without renumbering the indexes.
Implementation
final int index;
Member index within the database. Read role for which member accepts writes: a failover moves the primary without renumbering the indexes.
final int index;