DatabaseStatusReplica class

Replica

Implemented types

Constructors

DatabaseStatusReplica({required int index, required String role, required bool healthy, double? lagSeconds})
DatabaseStatusReplica.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
healthy bool
Whether the replica is healthy.
final
index int
StatefulSet pod index (0 = primary, 1+ = replicas).
final
lagSeconds double?
Replication lag in seconds (null for primary).
final
role String
Replica role: primary or replica.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited