connectionPort property
Database port for connections. Derived from the engine when the backing has not reported one yet.
Implementation
final int connectionPort;
Database port for connections. Derived from the engine when the backing has not reported one yet.
final int connectionPort;