fallbackReason property
Why the backend ran a different backup type than the one requested. Empty when the backup ran as requested.
Implementation
final String fallbackReason;
Why the backend ran a different backup type than the one requested. Empty when the backup ran as requested.
final String fallbackReason;