requestedType property

String requestedType
final

Backup type that was requested. Differs from type when the backend could not run the requested type and took a different one instead, in which case fallbackReason explains why. Empty for backups taken before the requested type was recorded.

Implementation

final String requestedType;