DedicatedDatabaseBranchList class

BranchList

Implemented types

Constructors

DedicatedDatabaseBranchList({required int total, required List<DedicatedDatabaseBranch> branches})
DedicatedDatabaseBranchList.fromMap(Map<String, dynamic> map)
factory

Properties

branches List<DedicatedDatabaseBranch>
List of branches.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of branches.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited