DedicatedDatabaseExecutionColumn class

ExecutionColumn

Implemented types

Constructors

DedicatedDatabaseExecutionColumn({required String name, required String type})
DedicatedDatabaseExecutionColumn.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Column name as returned by the database.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Engine-specific column type (e.g. int4, text, timestamptz).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited