type property
Operation type, such as provision, update, restore, pausing, resuming, failover, backup-create or cross-region-enable.
Implementation
final String type;
Operation type, such as provision, update, restore, pausing, resuming, failover, backup-create or cross-region-enable.
final String type;