DedicatedDatabasePITRWindows class

PITRWindows

Implemented types

Constructors

DedicatedDatabasePITRWindows({required String earliest, required String latest})
DedicatedDatabasePITRWindows.fromMap(Map<String, dynamic> map)
factory

Properties

earliest String
Earliest available recovery point.
final
hashCode int
The hash code for this object.
no setterinherited
latest String
Latest available recovery point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited