syncAcknowledgements property
Number of standby acknowledgements the primary waits for before a write is committed. Zero means writes are acknowledged locally.
Implementation
final int syncAcknowledgements;
Number of standby acknowledgements the primary waits for before a write is committed. Zero means writes are acknowledged locally.
final int syncAcknowledgements;