DedicatedDatabaseRestoration class

Restoration

Implemented types

Constructors

DedicatedDatabaseRestoration({required String $id, required String $createdAt, required String databaseId, required String sourceDatabaseId, required String projectId, required String backupId, required String type, required String status, required String targetTime, required String startedAt, required String completedAt, required String error})
DedicatedDatabaseRestoration.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Restoration creation time in ISO 8601 format.
final
$id String
Restoration ID.
final
backupId String
Backup ID used for restoration (null for PITR).
final
completedAt String
Restoration completion time in ISO 8601 format.
final
databaseId String
Database ID being restored into.
final
error String
Error message if restoration failed.
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
Project ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceDatabaseId String
Source database ID when restoring a backup into another database.
final
startedAt String
Restoration start time in ISO 8601 format.
final
status String
Restoration status. Possible values: pending (queued for processing), running (currently in progress), completed (successfully finished), failed (encountered an error).
final
targetTime String
Target time for PITR restoration in ISO 8601 format.
final
type String
Restoration type. Possible values: backup (restore from a specific backup snapshot), pitr (point-in-time recovery to a specific timestamp).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited