DedicatedDatabaseSpecificationList class

SpecificationList

Implemented types

Constructors

DedicatedDatabaseSpecificationList({required List<DedicatedDatabaseSpecification> specifications, required int total, required DedicatedDatabaseSpecificationPricing pricing})
DedicatedDatabaseSpecificationList.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pricing DedicatedDatabaseSpecificationPricing
Overage and add-on pricing shared across all specifications.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specifications List<DedicatedDatabaseSpecification>
List of dedicated database specifications.
final
total int
Total number of specifications.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited