DedicatedDatabaseSpecificationPricing class

SpecificationPricing

Implemented types

Constructors

DedicatedDatabaseSpecificationPricing({required double storageOverageRate, required double bandwidthOverageRate, required double replicaRate, required double crossRegionReplicaRate, required double pitrRate})
DedicatedDatabaseSpecificationPricing.fromMap(Map<String, dynamic> map)
factory

Properties

bandwidthOverageRate double
Price per GB of bandwidth above the included amount, per month, in USD.
final
crossRegionReplicaRate double
Cross-region replica price as a fraction of the specification cost.
final
hashCode int
The hash code for this object.
no setterinherited
pitrRate double
Point-in-time recovery price as a fraction of the specification cost.
final
replicaRate double
High availability replica price as a fraction of the specification cost.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageOverageRate double
Price per GB of storage above the included amount, per month, in USD.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited