Embedding class

Embedding

Implemented types

Constructors

Embedding({required String model, required int dimension, required List<double> embedding, required String error})
Embedding.fromMap(Map<String, dynamic> map)
factory

Properties

dimension int
Number of dimensions for each embedding vector.
final
embedding List<double>
Embedding vector values. If an error occurs, this will be an empty array.
final
error String
Error message if embedding generation fails. Empty string if no error.
final
hashCode int
The hash code for this object.
no setterinherited
model String
Embedding model used to generate embeddings.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited