parentResourceType property

String parentResourceType
final

Plural noun for the parent resource that contains the insight's resource, e.g. an insight about a column index on a table → resourceType=indexes, parentResourceType=tables. Empty when the resource has no parent.

Implementation

final String parentResourceType;