method property
Public API method on the chosen service the client should invoke when this CTA is triggered.
Implementation
final String method;
Public API method on the chosen service the client should invoke when this CTA is triggered.
final String method;