Key class
Key
- Implemented types
Constructors
Properties
- $createdAt → String
-
Key creation date in ISO 8601 format.
final
- $id → String
-
Key ID.
final
- $updatedAt → String
-
Key update date in ISO 8601 format.
final
- accessedAt → String
-
Most recent access date in ISO 8601 format. This attribute is only updated again after 24 hours.
final
- expire → String
-
Key expiration date in ISO 8601 format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Key name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
Allowed permission scopes.
final
-
sdks
→ List<
String> -
List of SDK user agents that used this key.
final
- secret → String
-
Secret key.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited