userEmail property
User email of the actor recorded for this log. During impersonation, this is the original impersonator.
Implementation
final String userEmail;
User email of the actor recorded for this log. During impersonation, this is the original impersonator.
final String userEmail;