userId property
User ID of the actor recorded for this log. During impersonation, this is the original impersonator, not the impersonated target user.
Implementation
final String userId;
User ID of the actor recorded for this log. During impersonation, this is the original impersonator, not the impersonated target user.
final String userId;