userName property
User name of the actor recorded for this log. During impersonation, this is the original impersonator.
Implementation
final String userName;
User name of the actor recorded for this log. During impersonation, this is the original impersonator.
final String userName;