MockNumber class

Mock Number

Implemented types

Constructors

MockNumber({required String number, required String otp, required String $createdAt, required String $updatedAt})
MockNumber.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Attribute creation date in ISO 8601 format.
final
$updatedAt String
Attribute update date in ISO 8601 format.
final
hashCode int
The hash code for this object.
no setterinherited
number String
Mock phone number for testing phone authentication. Useful for testing phone authentication without sending an SMS.
final
otp String
Mock OTP for the number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited