number property
Mock phone number for testing phone authentication. Useful for testing phone authentication without sending an SMS.
Implementation
final String number;
Mock phone number for testing phone authentication. Useful for testing phone authentication without sending an SMS.
final String number;