phone property
Mock phone number for testing phone authentication. Useful for testing phone authentication without sending an SMS.
Implementation
final String phone;
Mock phone number for testing phone authentication. Useful for testing phone authentication without sending an SMS.
final String phone;