OAuth2Apple class

OAuth2Apple

Implemented types

Constructors

OAuth2Apple({required String $id, required bool enabled, required String serviceId, required String keyId, required String teamId, required String p8File})
OAuth2Apple.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
OAuth2 provider ID.
final
enabled bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode int
The hash code for this object.
no setterinherited
keyId String
Apple OAuth2 key ID.
final
p8File String
Apple OAuth2 .p8 private key file contents. The secret key wrapped by the PEM markers is 200 characters long.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceId String
Apple OAuth2 service ID.
final
teamId String
Apple OAuth2 team ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited