OAuth2Box class
OAuth2Box
- Implemented types
Constructors
Properties
- $id → String
-
OAuth2 provider ID.
final
- clientId → String
-
Box OAuth2 client ID.
final
- clientSecret → String
-
Box OAuth2 client secret.
final
- enabled → bool
-
OAuth2 provider is active and can be used to create sessions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited