OAuth2Dropbox class

OAuth2Dropbox

Implemented types

Constructors

OAuth2Dropbox({required String $id, required bool enabled, required String appKey, required String appSecret})
OAuth2Dropbox.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
OAuth2 provider ID.
final
appKey String
Dropbox OAuth2 app key.
final
appSecret String
Dropbox OAuth2 app secret.
final
enabled bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited