OAuth2Etsy class

OAuth2Etsy

Implemented types

Constructors

OAuth2Etsy({required String $id, required bool enabled, required String keyString, required String sharedSecret})
OAuth2Etsy.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
OAuth2 provider ID.
final
enabled bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode int
The hash code for this object.
no setterinherited
keyString String
Etsy OAuth2 keystring.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedSecret String
Etsy OAuth2 shared secret.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited