OAuth2Facebook class

OAuth2Facebook

Implemented types

Constructors

OAuth2Facebook({required String $id, required bool enabled, required String appId, required String appSecret})
OAuth2Facebook.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
OAuth2 provider ID.
final
appId String
Facebook OAuth2 app ID.
final
appSecret String
Facebook OAuth2 app secret.
final
enabled bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited