OAuth2Gitlab class
OAuth2Gitlab
- Implemented types
Constructors
- OAuth2Gitlab({required String $id, required bool enabled, required String applicationId, required String secret, required String endpoint})
-
OAuth2Gitlab.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
OAuth2 provider ID.
final
- applicationId → String
-
GitLab OAuth2 application ID.
final
- enabled → bool
-
OAuth2 provider is active and can be used to create sessions.
final
- endpoint → String
-
GitLab OAuth2 endpoint URL. Defaults to https://gitlab.com for self-hosted instances.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret → String
-
GitLab OAuth2 secret.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited