OAuth2Google class
OAuth2Google
- Implemented types
Constructors
- OAuth2Google({required String $id, required bool enabled, required String clientId, required String clientSecret})
-
OAuth2Google.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
OAuth2 provider ID.
final
- clientId → String
-
Google OAuth2 client ID.
final
- clientSecret → String
-
Google OAuth2 client secret.
final
- enabled → bool
-
OAuth2 provider is active and can be used to create sessions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited