OAuth2Linkedin class

OAuth2Linkedin

Implemented types

Constructors

OAuth2Linkedin({required String $id, required bool enabled, required String clientId, required String primaryClientSecret})
OAuth2Linkedin.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
OAuth2 provider ID.
final
clientId String
LinkedIn OAuth2 client ID.
final
enabled bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode int
The hash code for this object.
no setterinherited
primaryClientSecret String
LinkedIn OAuth2 primary client secret.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited