OAuth2Microsoft class

OAuth2Microsoft

Implemented types

Constructors

OAuth2Microsoft({required String $id, required bool enabled, required String applicationId, required String applicationSecret, required String tenant})
OAuth2Microsoft.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
OAuth2 provider ID.
final
applicationId String
Microsoft OAuth2 application ID.
final
applicationSecret String
Microsoft OAuth2 application secret.
final
enabled bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenant String
Microsoft Entra ID tenant identifier. Use 'common', 'organizations', 'consumers' or a specific tenant ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited