maxAge property
Maximum authentication age in seconds. When set, the user must have authenticated within this many seconds.
Implementation
final int? maxAge;
Maximum authentication age in seconds. When set, the user must have authenticated within this many seconds.
final int? maxAge;