wellKnownURL property
OpenID Connect well-known configuration URL. When set, authorization, token, and user info endpoints can be discovered automatically.
Implementation
final String wellKnownURL;
OpenID Connect well-known configuration URL. When set, authorization, token, and user info endpoints can be discovered automatically.
final String wellKnownURL;