OAuth2ProviderList class

OAuth2 Providers List

Implemented types

Constructors

OAuth2ProviderList({required int total, required List providers})
OAuth2ProviderList.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
providers List
List of OAuth2 providers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of OAuth2 providers in the given project.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited