OAuth2Tradeshift class

OAuth2Tradeshift

Implemented types

Constructors

OAuth2Tradeshift({required String $id, required bool enabled, required String oauth2ClientId, required String oauth2ClientSecret})
OAuth2Tradeshift.fromMap(Map<String, dynamic> map)
factory

Properties

$id → String
OAuth2 provider ID.
final
enabled → bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode → int
The hash code for this object.
no setterinherited
oauth2ClientId → String
Tradeshift OAuth2 client ID.
final
oauth2ClientSecret → String
Tradeshift OAuth2 client secret.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited