OAuth2X class

OAuth2X

Implemented types

Constructors

OAuth2X({required String $id, required bool enabled, required String customerKey, required String secretKey})
OAuth2X.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
OAuth2 provider ID.
final
customerKey String
X OAuth2 customer key.
final
enabled bool
OAuth2 provider is active and can be used to create sessions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String
X OAuth2 secret key.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited