redirectUrl property
URL the end user should be redirected to when the flow can complete without consent. Empty when consent is still required.
Implementation
final String redirectUrl;
URL the end user should be redirected to when the flow can complete without consent. Empty when consent is still required.
final String redirectUrl;