authorizationDetails property
Authorization details the user consented to, as a JSON string. Each entry has a type plus project-defined fields.
Implementation
final String authorizationDetails;
Authorization details the user consented to, as a JSON string. Each entry has a type plus project-defined fields.
final String authorizationDetails;