appId property
ID of the registered app the token family was issued to. Empty for URL-form (CIMD) clients.
Implementation
final String appId;
ID of the registered app the token family was issued to. Empty for URL-form (CIMD) clients.
final String appId;