authorizationDetails property
Authorization details granted on the token family, as a JSON string. Each entry has a type plus project-defined fields.
Implementation
final String authorizationDetails;
Authorization details granted on the token family, as a JSON string. Each entry has a type plus project-defined fields.
final String authorizationDetails;