cimdUrl property
Client ID metadata document URL of the client the token family was issued to. Empty for registered apps.
Implementation
final String cimdUrl;
Client ID metadata document URL of the client the token family was issued to. Empty for registered apps.
final String cimdUrl;