Oauth2DeviceAuthorization class

OAuth2 Device Authorization

Implemented types

Constructors

Oauth2DeviceAuthorization({required String device_code, required String user_code, required String verification_uri, required String verification_uri_complete, required int expires_in, required int interval})
Oauth2DeviceAuthorization.fromMap(Map<String, dynamic> map)
factory

Properties

device_code String
Device verification code used by the client to poll the token endpoint.
final
expires_in int
Lifetime of the device code and user code in seconds.
final
hashCode int
The hash code for this object.
no setterinherited
interval int
Minimum polling interval for the token endpoint in seconds.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user_code String
Short code the end user enters on the verification page.
final
verification_uri String
URL where the end user enters the user code.
final
verification_uri_complete String
Verification URL with the user code prefilled as a query parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited