Oauth2Grant class

OAuth2 Grant

Implemented types

Constructors

Oauth2Grant({required String $id, required String $createdAt, required String $updatedAt, required String userId, required String appId, required List<String> scopes, required List<String> resources, required String authorizationDetails, required String prompt, required String redirectUri, required int authTime, required String expire})
Oauth2Grant.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Grant creation time in ISO 8601 format.
final
$id String
Grant ID.
final
$updatedAt String
Grant update date in ISO 8601 format.
final
appId String
ID of the OAuth2 client (app) the grant was requested for.
final
authorizationDetails String
Requested authorization_details the user is being asked to consent to, as a JSON string. Each entry has a type plus project-defined fields.
final
authTime int
Unix timestamp of when the user last authenticated.
final
expire String
Grant expiration time in ISO 8601 format.
final
hashCode int
The hash code for this object.
no setterinherited
prompt String
OIDC prompt directive the consent screen should honor. Space-separated list of: login, consent, select_account.
final
redirectUri String
Redirect URI the user will be sent to after the flow completes.
final
resources List<String>
Requested RFC 8707 resource indicators the user is being asked to consent to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
Requested OAuth2 scopes the user is being asked to consent to.
final
userId String
ID of the user the grant belongs to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited