authorizationDetails property
Requested authorization_details the user is being asked to consent to, as a JSON string. Each entry has a type plus project-defined fields.
Implementation
final String authorizationDetails;
Requested authorization_details the user is being asked to consent to, as a JSON string. Each entry has a type plus project-defined fields.
final String authorizationDetails;