Oauth2OrganizationList class
OAuth2 accessible organizations list
- Implemented types
Constructors
-
Oauth2OrganizationList({required int total, required List<
Oauth2Organization> organizations}) -
Oauth2OrganizationList.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
organizations
→ List<
Oauth2Organization> -
List of organizations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
Total number of organizations that matched your query.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited