endpoint property
API endpoint of the region the project is deployed in. Empty when the region has no public hostname configured.
Implementation
final String endpoint;
API endpoint of the region the project is deployed in. Empty when the region has no public hostname configured.
final String endpoint;