redirectUrl property
URL the end user should be redirected to after the grant is rejected, carrying an access_denied error.
Implementation
final String redirectUrl;
URL the end user should be redirected to after the grant is rejected, carrying an access_denied error.
final String redirectUrl;