Organization class

Organization

Implemented types

Constructors

Organization({required String $id, required String $createdAt, required String $updatedAt, required String name, required int total, required Preferences prefs, required int billingBudget, required List<int> budgetAlerts, required String billingPlan, required String billingPlanId, required BillingPlan billingPlanDetails, required String billingEmail, required String billingStartDate, required String billingCurrentInvoiceDate, required String billingNextInvoiceDate, required String billingTrialStartDate, required int billingTrialDays, required String billingAggregationId, required String billingInvoiceId, required String paymentMethodId, required String billingAddressId, required String backupPaymentMethodId, required String status, required String remarks, required String agreementBAA, required String programManagerName, required String programManagerCalendar, required String programDiscordChannelName, required String programDiscordChannelUrl, BillingLimits? billingLimits, required String billingPlanDowngrade, required String billingTaxId, required bool markedForDeletion, required String platform, required List<String> projects})
Organization.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Team creation date in ISO 8601 format.
final
$id String
Team ID.
final
$updatedAt String
Team update date in ISO 8601 format.
final
agreementBAA String
Organization agreements
final
backupPaymentMethodId String
Backup payment method.
final
billingAddressId String
Default payment method.
final
billingAggregationId String
Current active aggregation id.
final
billingBudget int
Project budget limit
final
billingCurrentInvoiceDate String
Current invoice cycle start date.
final
billingEmail String
Billing email set for the organization.
final
billingInvoiceId String
Current active aggregation id.
final
billingLimits BillingLimits?
Billing limits reached
final
billingNextInvoiceDate String
Next invoice cycle start date.
final
billingPlan String
Organization's billing plan ID.
final
billingPlanDetails BillingPlan
Organization's billing plan.
final
billingPlanDowngrade String
Billing plan selected for downgrade.
final
billingPlanId String
Organization's billing plan ID.
final
billingStartDate String
Billing cycle start date.
final
billingTaxId String
Tax Id
final
billingTrialDays int
Number of trial days.
final
billingTrialStartDate String
Start date of trial.
final
budgetAlerts List<int>
Project budget limit
final
hashCode int
The hash code for this object.
no setterinherited
markedForDeletion bool
Marked for deletion
final
name String
Team name.
final
paymentMethodId String
Default payment method.
final
platform String
Product with which the organization is associated (appwrite or imagine)
final
prefs Preferences
Team preferences as a key-value object
final
programDiscordChannelName String
Program's discord channel name.
final
programDiscordChannelUrl String
Program's discord channel URL.
final
programManagerCalendar String
Program manager's calendar link.
final
programManagerName String
Program manager's name.
final
projects List<String>
Selected projects
final
remarks String
Remarks on team status.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
Team status.
final
total int
Total number of team members.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited