PlatformAndroid class

Platform Android

Implemented types

Constructors

PlatformAndroid({required String $id, required String $createdAt, required String $updatedAt, required String name, required PlatformType type, required String applicationId})
PlatformAndroid.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Platform creation date in ISO 8601 format.
final
$id String
Platform ID.
final
$updatedAt String
Platform update date in ISO 8601 format.
final
applicationId String
Android application ID.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Platform name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PlatformType
Platform type. Possible values are: windows, apple, android, linux, web.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited