PlatformList class

Platforms List

Implemented types

Constructors

PlatformList({required int total, required List platforms})
PlatformList.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
platforms List
List of platforms.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of platforms in the given project.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited