PolicyMembershipPrivacy class

Policy Membership Privacy

Implemented types

Constructors

PolicyMembershipPrivacy({required String $id, required bool userId, required bool userEmail, required bool userPhone, required bool userName, required bool userMFA})
PolicyMembershipPrivacy.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
Policy ID.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userEmail bool
Whether user email is visible in memberships.
final
userId bool
Whether user ID is visible in memberships.
final
userMFA bool
Whether user MFA status is visible in memberships.
final
userName bool
Whether user name is visible in memberships.
final
userPhone bool
Whether user phone is visible in memberships.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited