PolicyMfaFactors class

Policy MFA Factors

Implemented types

Constructors

PolicyMfaFactors({required String $id, required bool totp, required bool email, required bool phone, required bool custom})
PolicyMfaFactors.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
Policy ID.
final
custom bool
Whether the custom factor can be used to complete an MFA challenge.
final
email bool
Whether email can be used to complete an MFA challenge.
final
hashCode int
The hash code for this object.
no setterinherited
phone bool
Whether phone (SMS) can be used to complete an MFA challenge.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totp bool
Whether TOTP can be used to complete an MFA challenge.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited