PolicyUserLimit class

Policy User Limit

Implemented types

Constructors

PolicyUserLimit({required String $id, required int total})
PolicyUserLimit.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
Policy ID.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Maximum number of users allowed in the project. A value of 0 means the policy is disabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited