PostgresExtension class

Postgres extension

Implemented types

Constructors

PostgresExtension({required String key, required String name, required String description, required String category})
PostgresExtension.fromMap(Map<String, dynamic> map)
factory

Properties

category String
Category the extension belongs to.
final
description String
Short description of what the extension provides.
final
hashCode int
The hash code for this object.
no setterinherited
key String
Extension key used with CREATE EXTENSION.
final
name String
Human-readable extension name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited