Program class

Program

Implemented types

Constructors

Program({required String $id, required String title, required String description, required String tag, required String icon, required String url, required bool active, required bool xexternal, required String billingPlanId})
Program.fromMap(Map<String, dynamic> map)
factory

Properties

$id String
Program ID
final
active bool
Whether this program is active
final
billingPlanId String
Billing plan ID that this is program is associated with.
final
description String
Program description
final
hashCode int
The hash code for this object.
no setterinherited
icon String
Program icon for highlighting on console
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
Program tag for highlighting on console
final
title String
Program title
final
url String
URL for more information on this program
final
xexternal bool
Whether this program is external
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited