authMembershipsUserPhone property
Whether or not to show user phone numbers in the teams membership response.
Implementation
final bool authMembershipsUserPhone;
Whether or not to show user phone numbers in the teams membership response.
final bool authMembershipsUserPhone;