authMockNumbers property
An array of mock numbers and their corresponding verification codes (OTPs).
Implementation
final List<MockNumber> authMockNumbers;
An array of mock numbers and their corresponding verification codes (OTPs).
final List<MockNumber> authMockNumbers;