oAuth2ServerPublicRefreshTokenDuration property
OAuth2 server refresh token duration in seconds for public clients (SPAs, mobile, native)
Implementation
final int oAuth2ServerPublicRefreshTokenDuration;
OAuth2 server refresh token duration in seconds for public clients (SPAs, mobile, native)
final int oAuth2ServerPublicRefreshTokenDuration;