oAuth2ServerRefreshTokenDuration property
OAuth2 server refresh token duration in seconds for confidential clients
Implementation
final int oAuth2ServerRefreshTokenDuration;
OAuth2 server refresh token duration in seconds for confidential clients
final int oAuth2ServerRefreshTokenDuration;