oAuth2ServerUserCodeLength property
Number of characters in the device flow user code, excluding the formatting separator.
Implementation
final int? oAuth2ServerUserCodeLength;
Number of characters in the device flow user code, excluding the formatting separator.
final int? oAuth2ServerUserCodeLength;