oAuth2ServerVerificationUrl property

String? oAuth2ServerVerificationUrl
final

URL to your application page where users enter the device flow user code. Empty when the Device Authorization Grant is not configured.

Implementation

final String? oAuth2ServerVerificationUrl;