ProjectProtocol class

ProjectProtocol

Implemented types

Constructors

ProjectProtocol({required ProjectProtocolId $id, required bool enabled})
ProjectProtocol.fromMap(Map<String, dynamic> map)
factory

Properties

$id ProjectProtocolId
Protocol ID.
final
enabled bool
Protocol status.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited