ProxyInvalidation class

Invalidation

Implemented types

Constructors

ProxyInvalidation({required String domain, required String type, required String reference, required String status})
ProxyInvalidation.fromMap(Map<String, dynamic> map)
factory

Properties

domain String
Domain name.
final
hashCode int
The hash code for this object.
no setterinherited
reference String
Invalidated reference. Depending on type this is a cache tag name, a URL path, or empty when type is all.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
Invalidation status.
final
type String
Invalidation type. Possible values are "tag", "path", or "all".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited