reference property
Invalidated reference. Depending on type this is a cache tag name, a URL path, or empty when type is all.
Implementation
final String reference;
Invalidated reference. Depending on type this is a cache tag name, a URL path, or empty when type is all.
final String reference;