ProxyRule class

Rule

Implemented types

Constructors

ProxyRule({required String $id, required String $createdAt, required String $updatedAt, required String domain, required String type, required String trigger, required String redirectUrl, required int redirectStatusCode, required String deploymentId, ProxyRuleDeploymentResourceType? deploymentResourceType, required String deploymentResourceId, required String deploymentVcsProviderBranch, required ProxyRuleStatus status, required String logs, required String renewAt})
ProxyRule.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Rule creation date in ISO 8601 format.
final
$id String
Rule ID.
final
$updatedAt String
Rule update date in ISO 8601 format.
final
deploymentId String
ID of deployment. Used if type is "deployment"
final
deploymentResourceId String
ID of deployment's resource (site or function ID). Used if type is "deployment"
final
deploymentResourceType ProxyRuleDeploymentResourceType?
Type of deployment. Possible values are "function", "site". Used if rule's type is "deployment".
final
deploymentVcsProviderBranch String
Name of Git branch that updates rule. Used if type is "deployment"
final
domain String
Domain name.
final
hashCode int
The hash code for this object.
no setterinherited
logs String
Logs from rule verification or certificate generation. Certificate generation logs are prioritized if both are available.
final
redirectStatusCode int
Status code to apply during redirect. Used if type is "redirect"
final
redirectUrl String
URL to redirect to. Used if type is "redirect"
final
renewAt String
Certificate auto-renewal date in ISO 8601 format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ProxyRuleStatus
Domain verification status. Possible values are "unverified", "verifying", "verified"
final
trigger String
Defines how the rule was created. Possible values are "manual" or "deployment"
final
type String
Action definition for the rule. Possible values are "api", "deployment", or "redirect"
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited