Site class

Site

Implemented types

Constructors

Site({required String $id, required String $createdAt, required String $updatedAt, required String name, required bool enabled, required bool live, required bool logging, required String framework, required int deploymentRetention, required String deploymentId, required String deploymentCreatedAt, required String deploymentScreenshotLight, required String deploymentScreenshotDark, required String latestDeploymentId, required String latestDeploymentCreatedAt, required String latestDeploymentStatus, required List<Variable> vars, required int timeout, required String installCommand, required String buildCommand, required String startCommand, required String outputDirectory, required String installationId, required String providerRepositoryId, required String providerBranch, required String providerRootDirectory, required bool providerSilentMode, required String buildSpecification, required String runtimeSpecification, required String buildRuntime, required String adapter, required String fallbackFile})
Site.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Site creation date in ISO 8601 format.
final
$id String
Site ID.
final
$updatedAt String
Site update date in ISO 8601 format.
final
adapter String
Site framework adapter.
final
buildCommand String
The build command used to build the site.
final
buildRuntime String
Site build runtime.
final
buildSpecification String
Machine specification for deployment builds.
final
deploymentCreatedAt String
Active deployment creation date in ISO 8601 format.
final
deploymentId String
Site's active deployment ID.
final
deploymentRetention int
How many days to keep the non-active deployments before they will be automatically deleted.
final
deploymentScreenshotDark String
Screenshot of active deployment with dark theme preference file ID.
final
deploymentScreenshotLight String
Screenshot of active deployment with light theme preference file ID.
final
enabled bool
Site enabled.
final
fallbackFile String
Name of fallback file to use instead of 404 page. If null, Appwrite 404 page will be displayed.
final
framework String
Site framework.
final
hashCode int
The hash code for this object.
no setterinherited
installationId String
Site VCS (Version Control System) installation id.
final
installCommand String
The install command used to install the site dependencies.
final
latestDeploymentCreatedAt String
Latest deployment creation date in ISO 8601 format.
final
latestDeploymentId String
Site's latest deployment ID.
final
latestDeploymentStatus String
Status of latest deployment. Possible values are "waiting", "processing", "building", "ready", and "failed".
final
live bool
Is the site deployed with the latest configuration? This is set to false if you've changed an environment variables, entrypoint, commands, or other settings that needs redeploy to be applied. When the value is false, redeploy the site to update it with the latest configuration.
final
logging bool
When disabled, request logs will exclude logs and errors, and site responses will be slightly faster.
final
name String
Site name.
final
outputDirectory String
The directory where the site build output is located.
final
providerBranch String
VCS (Version Control System) branch name
final
providerRepositoryId String
VCS (Version Control System) Repository ID
final
providerRootDirectory String
Path to site in VCS (Version Control System) repository
final
providerSilentMode bool
Is VCS (Version Control System) connection is in silent mode? When in silence mode, no comments will be posted on the repository pull or merge requests
final
runtimeSpecification String
Machine specification for SSR executions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startCommand String
Custom command to use when starting site runtime.
final
timeout int
Site request timeout in seconds.
final
vars List<Variable>
Site variables.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited