Webhook class

Webhook

Implemented types

Constructors

Webhook({required String $id, required String $createdAt, required String $updatedAt, required String name, required String url, required List<String> events, required bool tls, required String authUsername, required String authPassword, required String secret, required bool enabled, required String logs, required int attempts})
Webhook.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Webhook creation date in ISO 8601 format.
final
$id String
Webhook ID.
final
$updatedAt String
Webhook update date in ISO 8601 format.
final
attempts int
Number of consecutive failed webhook attempts.
final
authPassword String
HTTP basic authentication password.
final
authUsername String
HTTP basic authentication username.
final
enabled bool
Indicates if this webhook is enabled.
final
events List<String>
Webhook trigger events.
final
hashCode int
The hash code for this object.
no setterinherited
logs String
Webhook error logs from the most recent failure.
final
name String
Webhook name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
Signature key which can be used to validate incoming webhook payloads. Only returned on creation and secret rotation.
final
tls bool
Indicates if SSL / TLS certificate verification is enabled.
final
url String
Webhook URL endpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited