secret property
Signature key which can be used to validate incoming webhook payloads. Only returned on creation and secret rotation.
Implementation
final String secret;
Signature key which can be used to validate incoming webhook payloads. Only returned on creation and secret rotation.
final String secret;