OrganizationKeyScopes enum

Inheritance
Available extensions

Values

projectsRead → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'projects.read')
projectsWrite → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'projects.write')
devKeysRead → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'devKeys.read')
devKeysWrite → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'devKeys.write')
organizationKeysRead → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'organization.keys.read')
organizationKeysWrite → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'organization.keys.write')
organizationMembershipsRead → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'organization.memberships.read')
organizationMembershipsWrite → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'organization.memberships.write')
organizationRead → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'organization.read')
organizationWrite → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'organization.write')
domainsRead → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'domains.read')
domainsWrite → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'domains.write')
keysRead → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'keys.read')
keysWrite → const OrganizationKeyScopes
const OrganizationKeyScopes(value: 'keys.write')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OrganizationKeyScopes>
A constant List of the values in this enum, in order of their declaration.