PasswordHash enum
Values
- sha1 → const PasswordHash
-
const PasswordHash(value: "sha1") - sha224 → const PasswordHash
-
const PasswordHash(value: "sha224") - sha256 → const PasswordHash
-
const PasswordHash(value: "sha256") - sha384 → const PasswordHash
-
const PasswordHash(value: "sha384") - sha512224 → const PasswordHash
-
const PasswordHash(value: "sha512/224") - sha512256 → const PasswordHash
-
const PasswordHash(value: "sha512/256") - sha512 → const PasswordHash
-
const PasswordHash(value: "sha512") - sha3224 → const PasswordHash
-
const PasswordHash(value: "sha3-224") - sha3256 → const PasswordHash
-
const PasswordHash(value: "sha3-256") - sha3384 → const PasswordHash
-
const PasswordHash(value: "sha3-384") - sha3512 → const PasswordHash
-
const PasswordHash(value: "sha3-512")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PasswordHash> - A constant List of the values in this enum, in order of their declaration.