ProjectAuthMethodId enum
Values
- emailPassword → const ProjectAuthMethodId
-
const ProjectAuthMethodId(value: 'email-password') - magicUrl → const ProjectAuthMethodId
-
const ProjectAuthMethodId(value: 'magic-url') - emailOtp → const ProjectAuthMethodId
-
const ProjectAuthMethodId(value: 'email-otp') - anonymous → const ProjectAuthMethodId
-
const ProjectAuthMethodId(value: 'anonymous') - invites → const ProjectAuthMethodId
-
const ProjectAuthMethodId(value: 'invites') - jwt → const ProjectAuthMethodId
-
const ProjectAuthMethodId(value: 'jwt') - phone → const ProjectAuthMethodId
-
const ProjectAuthMethodId(value: 'phone')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProjectAuthMethodId> - A constant List of the values in this enum, in order of their declaration.