ProjectServiceId enum

Inheritance
Available extensions

Values

account → const ProjectServiceId
const ProjectServiceId(value: 'account')
avatars → const ProjectServiceId
const ProjectServiceId(value: 'avatars')
databases → const ProjectServiceId
const ProjectServiceId(value: 'databases')
tablesdb → const ProjectServiceId
const ProjectServiceId(value: 'tablesdb')
locale → const ProjectServiceId
const ProjectServiceId(value: 'locale')
health → const ProjectServiceId
const ProjectServiceId(value: 'health')
project → const ProjectServiceId
const ProjectServiceId(value: 'project')
storage → const ProjectServiceId
const ProjectServiceId(value: 'storage')
teams → const ProjectServiceId
const ProjectServiceId(value: 'teams')
users → const ProjectServiceId
const ProjectServiceId(value: 'users')
vcs → const ProjectServiceId
const ProjectServiceId(value: 'vcs')
sites → const ProjectServiceId
const ProjectServiceId(value: 'sites')
functions → const ProjectServiceId
const ProjectServiceId(value: 'functions')
proxy → const ProjectServiceId
const ProjectServiceId(value: 'proxy')
graphql → const ProjectServiceId
const ProjectServiceId(value: 'graphql')
migrations → const ProjectServiceId
const ProjectServiceId(value: 'migrations')
messaging → const ProjectServiceId
const ProjectServiceId(value: 'messaging')
advisor → const ProjectServiceId
const ProjectServiceId(value: 'advisor')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProjectServiceId>
A constant List of the values in this enum, in order of their declaration.