ActivityEvent class
ActivityEvent
- Implemented types
Constructors
- ActivityEvent({required String $id, required String actorType, required String actorId, required String actorEmail, required String actorName, required String resourceParent, required String resourceType, required String resourceId, required String resource, required String event, required String userAgent, required String ip, required String mode, required String country, required String continentCode, required String city, required String subdivisions, required String isp, required String autonomousSystemNumber, required String autonomousSystemOrganization, required String connectionType, required String connectionUsageType, required String connectionOrganization, required String time, required String projectId, required String teamId, required String hostname, required String sdk, required String sdkVersion})
-
ActivityEvent.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
Event ID.
final
- actorEmail → String
-
Actor Email.
final
- actorId → String
-
Actor ID.
final
- actorName → String
-
Actor Name.
final
- actorType → String
-
Actor type.
final
- autonomousSystemNumber → String
-
Autonomous System Number (ASN).
final
- autonomousSystemOrganization → String
-
Organization that owns the ASN.
final
- city → String
-
City name.
final
- connectionOrganization → String
-
Registered organization of the IP.
final
- connectionType → String
-
Connection type (e.g. cable, cellular, corporate).
final
- connectionUsageType → String
-
User type (e.g. residential, business, hosting).
final
- continentCode → String
-
Continent code.
final
- country → String
-
Location.
final
- event → String
-
Event name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostname → String
-
Hostname.
final
- ip → String
-
IP address.
final
- isp → String
-
Internet service provider.
final
- mode → String
-
API mode when event triggered.
final
- projectId → String
-
Project ID.
final
- resource → String
-
Resource.
final
- resourceId → String
-
Resource ID.
final
- resourceParent → String
-
Resource parent.
final
- resourceType → String
-
Resource type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdk → String
-
Name of the SDK that triggered the event.
final
- sdkVersion → String
-
Version of the SDK that triggered the event.
final
- subdivisions → String
-
Region/state chain.
final
- teamId → String
-
Team ID.
final
- time → String
-
Log creation date in ISO 8601 format.
final
- userAgent → String
-
User agent.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited