ActivityEvent class
ActivityEvent
- Implemented types
Constructors
- ActivityEvent({required String $id, required String userType, required String userId, required String userEmail, required String userName, required String resourceParent, required String resourceType, required String resourceId, required String resource, required String event, required String userAgent, required String ip, required String mode, required String country, required String time, required String projectId, required String teamId, required String hostname, required String osCode, required String osName, required String osVersion, required String clientType, required String clientCode, required String clientName, required String clientVersion, required String clientEngine, required String clientEngineVersion, required String deviceName, required String deviceBrand, required String deviceModel, required String countryCode, required String countryName})
-
ActivityEvent.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
Event ID.
final
- clientCode → String
-
Client code name. View list of available options.
final
- clientEngine → String
-
Client engine name.
final
- clientEngineVersion → String
-
Client engine name.
final
- clientName → String
-
Client name.
final
- clientType → String
-
Client type.
final
- clientVersion → String
-
Client version.
final
- country → String
-
Location.
final
- countryCode → String
-
Country two-character ISO 3166-1 alpha code.
final
- countryName → String
-
Country name.
final
- deviceBrand → String
-
Device brand name.
final
- deviceModel → String
-
Device model name.
final
- deviceName → String
-
Device name.
final
- event → String
-
Event name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostname → String
-
Hostname.
final
- ip → String
-
IP address.
final
- mode → String
-
API mode when event triggered.
final
- osCode → String
-
Operating system code name. View list of available options.
final
- osName → String
-
Operating system name.
final
- osVersion → String
-
Operating system version.
final
- projectId → String
-
Project ID.
final
- resource → String
-
Resource.
final
- resourceId → String
-
Resource ID.
final
- resourceParent → String
-
Resource parent.
final
- resourceType → String
-
Resource type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- teamId → String
-
Team ID.
final
- time → String
-
Log creation date in ISO 8601 format.
final
- userAgent → String
-
User agent.
final
- userEmail → String
-
User Email.
final
- userId → String
-
User ID.
final
- userName → String
-
User Name.
final
- userType → String
-
User type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited