AdditionalResource class
AdditionalResource
- Implemented types
Constructors
- AdditionalResource({required String name, required String unit, required String currency, required double price, required int value, required String invoiceDesc})
-
AdditionalResource.fromMap(Map<
String, dynamic> map) -
factory
Properties
- currency → String
-
Price currency
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceDesc → String
-
Description on invoice
final
- name → String
-
Resource name
final
- price → double
-
Price
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit → String
-
Resource unit
final
- value → int
-
Resource value
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited