App class
App
- Implemented types
Constructors
-
App({required String $id, required String $createdAt, required String $updatedAt, required String name, required String description, required String clientUri, required String logoUri, required String privacyPolicyUrl, required String termsUrl, required List<
String> contacts, required String tagline, required List<String> tags, required List<String> labels, required List<String> images, required String supportUrl, required String dataDeletionUrl, required List<String> redirectUris, required List<String> postLogoutRedirectUris, required bool enabled, required String type, required bool deviceFlow, required String teamId, required String userId, required List<String> installationScopes, required String installationRedirectUrl, required List<AppSecret> secrets}) -
App.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
App creation time in ISO 8601 format.
final
- $id → String
-
App ID.
final
- $updatedAt → String
-
App update date in ISO 8601 format.
final
- clientUri → String
-
Application homepage URL shown to users during OAuth2 consent.
final
-
contacts
→ List<
String> -
Application support or security contact emails.
final
- dataDeletionUrl → String
-
Application data deletion URL shown to users during OAuth2 consent.
final
- description → String
-
Application description shown to users during OAuth2 consent.
final
- deviceFlow → bool
-
Whether this client may use the OAuth2 Device Authorization Grant (RFC 8628).
final
- enabled → bool
-
Whether the app is enabled or not.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
images
→ List<
String> -
Application image URLs shown to users during OAuth2 consent.
final
- installationRedirectUrl → String
-
URL users are redirected to after creating or updating an installation of this application. Empty for no redirect.
final
-
installationScopes
→ List<
String> -
Scopes the application requests when installed on a team. Organization-level and project-level scopes only.
final
-
labels
→ List<
String> -
Application labels. Read-only for clients; only a server SDK using a project API key can update them.
final
- logoUri → String
-
Application logo URL shown to users during OAuth2 consent.
final
- name → String
-
Application name.
final
-
postLogoutRedirectUris
→ List<
String> -
List of authorized post-logout redirect URIs for OpenID Connect RP-Initiated Logout. The logout endpoint only redirects users to URIs in this list after ending their session.
final
- privacyPolicyUrl → String
-
Application privacy policy URL shown to users during OAuth2 consent.
final
-
redirectUris
→ List<
String> -
List of authorized redirect URIs. These URIs can be used to redirect users after they authenticate.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secrets
→ List<
AppSecret> -
List of application secrets.
final
- supportUrl → String
-
Application support URL shown to users during OAuth2 consent.
final
- tagline → String
-
Application tagline shown to users during OAuth2 consent.
final
-
Application tags shown to users during OAuth2 consent.
final
- teamId → String
-
ID of team that owns the application, if owned by team. Otherwise, user ID will be used.
final
- termsUrl → String
-
Application terms of service URL shown to users during OAuth2 consent.
final
- type → String
-
OAuth2 client type.
publicfor SPAs, mobile, and native apps that cannot keep a client secret (PKCE required);confidentialfor server-side clients that authenticate with a client secret.final - userId → String
-
ID of user who owns the application, if owned by user. Otherwise, team ID will be used.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited