AppScope class
AppScope
- Implemented types
Constructors
Properties
- category → String
-
Scope category, used to group scopes on consent and installation screens.
final
- deprecated → bool
-
Whether the scope is deprecated. Deprecated scopes can still be requested but should not be offered for new grants.
final
- description → String
-
Human-readable description of what the scope grants.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
What the scope grants access to. One of
account,project, ororganization. Onlyprojectandorganizationscopes are installable.final - value → String
-
Scope value as requested by apps.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited