BillingLimits class
BillingLimits
- Implemented types
Constructors
Properties
- authPhone → int
-
Auth phone limit
final
- bandwidth → int
-
Bandwidth limit
final
- budgetLimit → int
-
Budget limit percentage
final
- executions → int
-
Executions limit
final
- GBHours → int
-
GBHours limit
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageTransformations → int
-
Image transformations limit
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → int
-
Storage limit
final
- users → int
-
Users limit
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited