BillingPlan class
billingPlan
- Implemented types
Constructors
-
BillingPlan({required String $id, required String name, required String desc, required int order, required double price, required int trial, required int bandwidth, required int storage, required int imageTransformations, required int screenshotsGenerated, required int members, required int webhooks, required int projects, required int platforms, required int users, required int teams, required int databases, required int databasesReads, required int databasesWrites, required int databasesBatchSize, required int buckets, required int fileSize, required int functions, required int sites, required int executions, required int executionsRetentionCount, required int GBHours, required int realtime, required int realtimeMessages, required int messages, required int topics, required int authPhone, required int domains, required int activityLogs, required int usageLogs, List<
String> ? usageLogsIntervals, required int projectInactivityDays, required int alertLimit, required UsageBillingPlan usage, required BillingPlanAddon addons, required bool budgetCapEnabled, required bool customSmtp, required bool emailBranding, required bool requiresPaymentMethod, required bool requiresBillingAddress, required bool isAvailable, required bool selfService, required bool budgeting, required bool supportsMockNumbers, required bool supportsOrganizationRoles, required bool supportsCredits, required bool supportsDisposableEmailValidation, required bool supportsCanonicalEmailValidation, required bool supportsFreeEmailValidation, required bool supportsCorporateEmailValidation, required bool supportsProjectSpecificRoles, required bool backupsEnabled, required bool usagePerProject, required BillingPlanSupportedAddons supportedAddons, required int backupPolicies, required int deploymentSize, required int buildSize, required bool databasesAllowEncrypt, BillingPlanLimits? limits, required BillingPlanGroup group, Program? program, BillingPlanDedicatedDatabaseLimits? dedicatedDatabases}) -
BillingPlan.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
Plan ID.
final
- activityLogs → int
-
Activity log days
final
- addons → BillingPlanAddon
-
Addons
final
- alertLimit → int
-
Alert threshold percentage
final
- authPhone → int
-
SMS authentications per month
final
- backupPolicies → int
-
How many policies does plan support
final
- backupsEnabled → bool
-
Does plan support backup policies.
final
- bandwidth → int
-
Bandwidth
final
- buckets → int
-
Buckets
final
- budgetCapEnabled → bool
-
Budget cap enabled or disabled.
final
- budgeting → bool
-
Does plan support budget cap
final
- buildSize → int
-
Maximum function and site deployment size in MB
final
- customSmtp → bool
-
Custom SMTP
final
- databases → int
-
Databases
final
- databasesAllowEncrypt → bool
-
Does the plan support encrypted string attributes or not.
final
- databasesBatchSize → int
-
Database batch size limit
final
- databasesReads → int
-
Database reads per month
final
- databasesWrites → int
-
Database writes per month
final
- dedicatedDatabases → BillingPlanDedicatedDatabaseLimits?
-
Dedicated database limits available to this plan.
final
- deploymentSize → int
-
Maximum function and site deployment size in MB
final
- desc → String
-
Plan description
final
- domains → int
-
Custom domains
final
- emailBranding → bool
-
Appwrite branding in email
final
- executions → int
-
Function executions
final
- executionsRetentionCount → int
-
Rolling max executions retained per function/site
final
- fileSize → int
-
File size
final
- functions → int
-
Functions
final
- GBHours → int
-
GB hours for functions
final
- group → BillingPlanGroup
-
Group of this billing plan for variants
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageTransformations → int
-
Image Transformations
final
- isAvailable → bool
-
Is the billing plan available
final
- limits → BillingPlanLimits?
-
Plan specific limits
final
- members → int
-
Members
final
- messages → int
-
Messages per month
final
- name → String
-
Plan name
final
- order → int
-
Plan order
final
- platforms → int
-
Platforms
final
-
Does plan enable premium support
final
- price → double
-
Price
final
- program → Program?
-
Details of the program this plan is a part of.
final
- projectInactivityDays → int
-
Number of days of console inactivity before a project is paused. 0 means pausing is disabled.
final
- projects → int
-
Projects
final
- realtime → int
-
Realtime connections
final
- realtimeMessages → int
-
Realtime messages
final
- requiresBillingAddress → bool
-
Does plan require billing address
final
- requiresPaymentMethod → bool
-
Does plan require payment method
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenshotsGenerated → int
-
Screenshots generated
final
- selfService → bool
-
Can user change the plan themselves
final
- sites → int
-
Sites
final
- storage → int
-
Storage
final
- supportedAddons → BillingPlanSupportedAddons
-
Supported addons for this plan
final
- supportsCanonicalEmailValidation → bool
-
Does plan support requiring canonical email addresses.
final
- supportsCorporateEmailValidation → bool
-
Does plan support restricting sign-ups to corporate email addresses only.
final
- supportsCredits → bool
-
Does plan support credit
final
- supportsDisposableEmailValidation → bool
-
Does plan support blocking disposable email addresses.
final
- supportsFreeEmailValidation → bool
-
Does plan support blocking free email addresses.
final
- supportsMockNumbers → bool
-
Does plan support mock numbers
final
- supportsOrganizationRoles → bool
-
Does plan support organization roles
final
- supportsProjectSpecificRoles → bool
-
Does plan support project-specific member roles.
final
- teams → int
-
Teams
final
- topics → int
-
Topics for messaging
final
- trial → int
-
Trial days
final
- usage → UsageBillingPlan
-
Additional resources
final
- usageLogs → int
-
Usage history days
final
-
usageLogsIntervals
→ List<
String> ? -
Usage log time intervals allowed for this plan (e.g. 15m, 1h, 1d).
final
- usagePerProject → bool
-
Whether usage addons are calculated per project.
final
- users → int
-
Users
final
- webhooks → int
-
Webhooks
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited