BillingPlanAddonDetails class
Details
- Implemented types
Constructors
Properties
- currency → String
-
Price currency
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceDesc → String
-
Description on invoice
final
- limit → int
-
Addon limit
final
- planIncluded → int
-
Addon plan included value
final
- price → double
-
Price
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supported → bool
-
Is the addon supported in the plan?
final
- type → String
-
Addon type
final
- value → int
-
Resource value
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited