Block class
Block
- Implemented types
Constructors
Properties
- $createdAt → String
-
Block creation date in ISO 8601 format.
final
- expiredAt → String?
-
Block expiration date in ISO 8601 format. Can be null if the block does not expire.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String?
-
Reason for the block. Can be null if no reason was provided.
final
- resourceId → String
-
Resource identifier that is blocked
final
- resourceType → String
-
Resource type that is blocked
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited