DatabaseStatusVolume class
Volume
- Implemented types
Constructors
- DatabaseStatusVolume({required String path, required String usedPercent, required String available, required bool mounted})
-
DatabaseStatusVolume.fromMap(Map<
String, dynamic> map) -
factory
Properties
- available → String
-
Available storage space.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether the volume is mounted.
final
- path → String
-
Mount path of the volume.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usedPercent → String
-
Percentage of storage used.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited