DedicatedDatabaseBackupStorage class
BackupStorageConfig
- Implemented types
Constructors
- DedicatedDatabaseBackupStorage({required String provider, required String bucket, required String region, required String prefix, required String endpoint})
-
DedicatedDatabaseBackupStorage.fromMap(Map<
String, dynamic> map) -
factory
Properties
- bucket → String
-
Storage bucket or container name.
final
- endpoint → String
-
Custom endpoint for S3-compatible storage.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- prefix → String
-
Object key prefix for backups.
final
- provider → String
-
Storage provider. Possible values: s3 (Amazon S3 or S3-compatible), gcs (Google Cloud Storage), azure (Azure Blob Storage).
final
- region → String
-
Storage region.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited