DedicatedDatabaseExtensions class
Extensions
- Implemented types
Constructors
-
DedicatedDatabaseExtensions({required List<
String> installed, required List<String> available, required List<PostgresExtension> metadata}) -
DedicatedDatabaseExtensions.fromMap(Map<
String, dynamic> map) -
factory
Properties
-
available
→ List<
String> -
List of available extensions that can be installed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
installed
→ List<
String> -
List of installed extensions.
final
-
metadata
→ List<
PostgresExtension> -
Curated metadata (display name, description, category) for each available extension.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited