lagSeconds property
Replication lag in seconds. Null when the lag is not known: a primary has none to report, and a member the backend has not probed has none yet.
Implementation
final double? lagSeconds;
Replication lag in seconds. Null when the lag is not known: a primary has none to report, and a member the backend has not probed has none yet.
final double? lagSeconds;