DedicatedDatabaseOperation class
Operation
- Implemented types
Constructors
- DedicatedDatabaseOperation({required String $id, required String $createdAt, required String databaseId, required String type, required String status, required int attempts, String? requestedAt, String? startedAt, String? completedAt, required String errorCode, required String errorMessage})
-
DedicatedDatabaseOperation.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
Operation creation time in ISO 8601 format.
final
- $id → String
-
Operation ID.
final
- attempts → int
-
Number of times this operation has been attempted.
final
- completedAt → String?
-
Time the operation reached a terminal state, in ISO 8601 format.
final
- databaseId → String
-
Database ID the operation ran against.
final
- errorCode → String
-
Machine-readable failure code.
LockLostmarks an attempt that was fenced and abandoned because another worker took over the database.final - errorMessage → String
-
Failure message if the operation failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestedAt → String?
-
Time the operation was requested, in ISO 8601 format.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → String?
-
Time the operation started, in ISO 8601 format.
final
- status → String
-
Operation status. Possible values: running (in progress), completed (finished successfully), failed (ended in an error).
final
- type → String
-
Operation type, such as provision, update, restore, pausing, resuming, failover, backup-create or cross-region-enable.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited