DedicatedDatabaseSpecification class
Specification
- Implemented types
Constructors
- DedicatedDatabaseSpecification({required String slug, required String name, required double price, required int cpu, required int memory, required int maxConnections, required int includedStorage, required int includedBandwidth, required bool enabled})
-
DedicatedDatabaseSpecification.fromMap(Map<
String, dynamic> map) -
factory
Properties
- cpu → int
-
Allocated CPU in millicores.
final
- enabled → bool
-
Whether the specification is available on the current plan.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includedBandwidth → int
-
Included bandwidth in GB before overage charges apply.
final
- includedStorage → int
-
Included storage in GB before overage charges apply.
final
- maxConnections → int
-
Maximum number of concurrent connections.
final
- memory → int
-
Allocated memory in MB.
final
- name → String
-
Human readable specification name.
final
- price → double
-
Monthly price of the specification in USD.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String
-
Specification slug. Use this value when creating a dedicated database.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited