EmailTemplate class
EmailTemplate
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → String
-
Template locale
final
- message → String
-
Template message
final
- replyToEmail → String
-
Reply to email address
final
- replyToName → String
-
Reply to name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderEmail → String
-
Email of the sender
final
- senderName → String
-
Name of the sender
final
- subject → String
-
Email subject
final
- templateId → String
-
Template type
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited