MockNumber class

Mock Number

Implemented types

Constructors

MockNumber({required String phone, required String otp})
MockNumber.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
otp String
Mock OTP for the number.
final
phone String
Mock phone number for testing phone authentication. Useful for testing phone authentication without sending an SMS.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited