OAuth2Oidc class
OAuth2Oidc
- Implemented types
Constructors
-
OAuth2Oidc({required String $id, required bool enabled, required String clientId, required String clientSecret, required String wellKnownURL, required String authorizationURL, required String tokenURL, required String userInfoURL, required List<
OAuth2OidcPrompt> prompt, int? maxAge}) -
OAuth2Oidc.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
OAuth2 provider ID.
final
-
OpenID Connect authorization endpoint URL.
final
- clientId → String
-
OpenID Connect OAuth2 client ID.
final
- clientSecret → String
-
OpenID Connect OAuth2 client secret.
final
- enabled → bool
-
OAuth2 provider is active and can be used to create sessions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAge → int?
-
Maximum authentication age in seconds. When set, the user must have authenticated within this many seconds.
final
-
prompt
→ List<
OAuth2OidcPrompt> -
OpenID Connect prompt values controlling the authentication and consent screens.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenURL → String
-
OpenID Connect token endpoint URL.
final
- userInfoURL → String
-
OpenID Connect user info endpoint URL.
final
- wellKnownURL → String
-
OpenID Connect well-known configuration URL. When set, authorization, token, and user info endpoints can be discovered automatically.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited