Oauth2Approve class
OAuth2 Approve
- Implemented types
Constructors
- Oauth2Approve({required String redirectUrl})
-
Oauth2Approve.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirectUrl → String
-
URL the end user should be redirected to after the grant is approved, carrying the authorization
codeand/orid_tokenalong with the originalstate.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited