redirectUrl property
URL the end user should be redirected to after the grant is approved, carrying the authorization code and/or id_token along with the original state.
Implementation
final String redirectUrl;
URL the end user should be redirected to after the grant is approved, carrying the authorization code and/or id_token along with the original state.
final String redirectUrl;