Oauth2Consent class
OAuth2 Consent
- Implemented types
Constructors
-
Oauth2Consent({required String $id, required String $createdAt, required String $updatedAt, required String userId, required String appId, required String cimdUrl, required List<
String> scopes, required List<String> resources, required String authorizationDetails, required String expire}) -
Oauth2Consent.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
Consent creation time in ISO 8601 format.
final
- $id → String
-
Consent ID.
final
- $updatedAt → String
-
Consent update date in ISO 8601 format.
final
- appId → String
-
ID of the registered app the consent was given to. Empty for URL-form (CIMD) clients.
final
-
Authorization details the user consented to, as a JSON string. Each entry has a
typeplus project-defined fields.final - cimdUrl → String
-
Client ID metadata document URL of the client the consent was given to. Empty for registered apps.
final
- expire → String
-
Consent expiration time in ISO 8601 format. Empty when the consent has no token-bound expiry yet.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resources
→ List<
String> -
RFC 8707 resource indicators the user consented to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
OAuth2 scopes the user consented to.
final
- userId → String
-
ID of the user the consent belongs to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited