Oauth2ConsentToken class
OAuth2 Consent Token
- Implemented types
Constructors
-
Oauth2ConsentToken({required String $id, required String $createdAt, required String $updatedAt, required String consentId, required String userId, required String appId, required String cimdUrl, required List<
String> scopes, required List<String> resources, required String authorizationDetails, required String expire}) -
Oauth2ConsentToken.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
Token creation time in ISO 8601 format.
final
- $id → String
-
Token family ID.
final
- $updatedAt → String
-
Token update date in ISO 8601 format. Refreshing the token family updates this.
final
- appId → String
-
ID of the registered app the token family was issued to. Empty for URL-form (CIMD) clients.
final
-
Authorization details granted on the token family, as a JSON string. Each entry has a
typeplus project-defined fields.final - cimdUrl → String
-
Client ID metadata document URL of the client the token family was issued to. Empty for registered apps.
final
- consentId → String
-
ID of the consent the token family was issued under.
final
- expire → String
-
Expiration time of the current access token of this family in ISO 8601 format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resources
→ List<
String> -
RFC 8707 resource indicators granted on the token family.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
OAuth2 scopes granted on the token family.
final
- userId → String
-
ID of the user the token family belongs to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited