Oauth2Project class
OAuth2 Project
- Implemented types
Constructors
- Oauth2Project({required String $id, required String region, required String endpoint})
-
Oauth2Project.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
Project ID.
final
- endpoint → String
-
API endpoint of the region the project is deployed in. Empty when the region has no public hostname configured.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- region → String
-
Region ID the project is deployed in.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited