Oauth2ProjectList class
OAuth2 accessible projects list
- Implemented types
Constructors
-
Oauth2ProjectList({required int total, required List<
Oauth2Project> projects}) -
Oauth2ProjectList.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
projects
→ List<
Oauth2Project> -
List of projects.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
Total number of projects that matched your query.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited