Oauth2Token class
OAuth2 Token
- Implemented types
Constructors
Properties
- access_token → String
-
OAuth2 access token.
final
-
Granted RFC 9396 authorization details as a JSON string.
final
- expires_in → int
-
Access token lifetime in seconds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id_token → String?
-
OpenID Connect ID token. Returned when the
openidscope is granted.final - refresh_token → String
-
OAuth2 refresh token.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
Space-separated scopes granted to the access token.
final
- token_type → String
-
OAuth2 token type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited