PolicyPasswordStrength class
Policy Password Strength
- Implemented types
Constructors
- PolicyPasswordStrength({required String $id, required int min, required bool uppercase, required bool lowercase, required bool number, required bool symbols})
-
PolicyPasswordStrength.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $id → String
-
Policy ID.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lowercase → bool
-
Whether passwords must include at least one lowercase letter.
final
- min → int
-
Minimum password length required for user passwords.
final
- number → bool
-
Whether passwords must include at least one number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbols → bool
-
Whether passwords must include at least one symbol.
final
- uppercase → bool
-
Whether passwords must include at least one uppercase letter.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited