Project class
Project
- Implemented types
Constructors
-
Project({required String $id, required String $createdAt, required String $updatedAt, required String name, required String teamId, required List<
DevKey> devKeys, required bool smtpEnabled, required String smtpSenderName, required String smtpSenderEmail, required String smtpReplyToName, required String smtpReplyToEmail, required String smtpHost, required int smtpPort, required String smtpUsername, required String smtpPassword, required String smtpSecure, required int pingCount, required String pingedAt, required List<String> labels, required String status, required List<ProjectAuthMethod> authMethods, required List<ProjectService> services, required List<ProjectProtocol> protocols, required String region, required BillingLimits billingLimits, required List<Block> blocks, required String consoleAccessedAt}) -
Project.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
Project creation date in ISO 8601 format.
final
- $id → String
-
Project ID.
final
- $updatedAt → String
-
Project update date in ISO 8601 format.
final
-
authMethods
→ List<
ProjectAuthMethod> -
List of auth methods.
final
- billingLimits → BillingLimits
-
Billing limits reached
final
-
blocks
→ List<
Block> -
Project blocks information
final
- consoleAccessedAt → String
-
Last time the project was accessed via console. Used with plan's projectInactivityDays to determine if project is paused.
final
-
devKeys
→ List<
DevKey> -
Deprecated since 1.9.5: List of dev keys.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ List<
String> -
Labels for the project.
final
- name → String
-
Project name.
final
- pingCount → int
-
Number of times the ping was received for this project.
final
- pingedAt → String
-
Last ping datetime in ISO 8601 format.
final
-
protocols
→ List<
ProjectProtocol> -
List of protocols.
final
- region → String
-
Project region
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
services
→ List<
ProjectService> -
List of services.
final
- smtpEnabled → bool
-
Status for custom SMTP
final
- smtpHost → String
-
SMTP server host name
final
- smtpPassword → String
-
SMTP server password. This property is write-only and always returned empty.
final
- smtpPort → int
-
SMTP server port
final
- smtpReplyToEmail → String
-
SMTP reply to email
final
- smtpReplyToName → String
-
SMTP reply to name
final
- smtpSecure → String
-
SMTP server secure protocol
final
- smtpSenderEmail → String
-
SMTP sender email
final
- smtpSenderName → String
-
SMTP sender name
final
- smtpUsername → String
-
SMTP server username
final
- status → String
-
Project status
final
- teamId → String
-
Project team ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited