Project class

Project

Implemented types

Constructors

Project({required String $id, required String $createdAt, required String $updatedAt, required String name, required String description, required String teamId, required String url, required String legalName, required String legalCountry, required String legalState, required String legalCity, required String legalAddress, required String legalTaxId, required int authDuration, required int authLimit, required int authSessionsLimit, required int authPasswordHistory, required bool authPasswordDictionary, required bool authPersonalDataCheck, required bool authDisposableEmails, required bool authCanonicalEmails, required bool authFreeEmails, required List<MockNumber> authMockNumbers, required bool authSessionAlerts, required bool authMembershipsUserName, required bool authMembershipsUserEmail, required bool authMembershipsMfa, required bool authInvalidateSessions, required List<AuthProvider> oAuthProviders, required List platforms, required List<Webhook> webhooks, required List<Key> keys, required List<DevKey> devKeys, required bool smtpEnabled, required String smtpSenderName, required String smtpSenderEmail, required String smtpReplyTo, required String smtpHost, required int smtpPort, required String smtpUsername, required String smtpPassword, required String smtpSecure, required int pingCount, required String pingedAt, required List<String> labels, required String status, required bool authEmailPassword, required bool authUsersAuthMagicURL, required bool authEmailOtp, required bool authAnonymous, required bool authInvites, required bool authJWT, required bool authPhone, required bool serviceStatusForAccount, required bool serviceStatusForAvatars, required bool serviceStatusForDatabases, required bool serviceStatusForTablesdb, required bool serviceStatusForLocale, required bool serviceStatusForHealth, required bool serviceStatusForProject, required bool serviceStatusForStorage, required bool serviceStatusForTeams, required bool serviceStatusForUsers, required bool serviceStatusForVcs, required bool serviceStatusForSites, required bool serviceStatusForFunctions, required bool serviceStatusForProxy, required bool serviceStatusForGraphql, required bool serviceStatusForMigrations, required bool serviceStatusForMessaging, required bool protocolStatusForRest, required bool protocolStatusForGraphql, required bool protocolStatusForWebsocket, required String region, required BillingLimits billingLimits, required List<Block> blocks, required String consoleAccessedAt})
Project.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Project creation date in ISO 8601 format.
final
$id String
Project ID.
final
$updatedAt String
Project update date in ISO 8601 format.
final
authAnonymous bool
Anonymous auth method status
final
authCanonicalEmails bool
Whether or not to require canonical email addresses during signup and email updates.
final
authDisposableEmails bool
Whether or not to disallow disposable email addresses during signup and email updates.
final
authDuration int
Session duration in seconds.
final
authEmailOtp bool
Email (OTP) auth method status
final
authEmailPassword bool
Email/Password auth method status
final
authFreeEmails bool
Whether or not to disallow free email addresses during signup and email updates.
final
authInvalidateSessions bool
Whether or not all existing sessions should be invalidated on password change
final
authInvites bool
Invites auth method status
final
authJWT bool
JWT auth method status
final
authLimit int
Max users allowed. 0 is unlimited.
final
authMembershipsMfa bool
Whether or not to show user MFA status in the teams membership response.
final
authMembershipsUserEmail bool
Whether or not to show user emails in the teams membership response.
final
authMembershipsUserName bool
Whether or not to show user names in the teams membership response.
final
authMockNumbers List<MockNumber>
An array of mock numbers and their corresponding verification codes (OTPs).
final
authPasswordDictionary bool
Whether or not to check user's password against most commonly used passwords.
final
authPasswordHistory int
Max allowed passwords in the history list per user. Max passwords limit allowed in history is 20. Use 0 for disabling password history.
final
authPersonalDataCheck bool
Whether or not to check the user password for similarity with their personal data.
final
authPhone bool
Phone auth method status
final
authSessionAlerts bool
Whether or not to send session alert emails to users.
final
authSessionsLimit int
Max sessions allowed per user. 100 maximum.
final
authUsersAuthMagicURL bool
Magic URL auth method status
final
billingLimits BillingLimits
Billing limits reached
final
blocks List<Block>
Project blocks information
final
consoleAccessedAt String
Last time the project was accessed via console. Used with plan's projectInactivityDays to determine if project is paused.
final
description String
Project description.
final
devKeys List<DevKey>
List of dev keys.
final
hashCode int
The hash code for this object.
no setterinherited
keys List<Key>
List of API Keys.
final
labels List<String>
Labels for the project.
final
legalAddress String
Company Address.
final
legalCity String
City name.
final
legalCountry String
Country code in ISO 3166-1 two-character format.
final
legalName String
Company legal name.
final
legalState String
State name.
final
legalTaxId String
Company Tax ID.
final
Project logo file ID.
final
name String
Project name.
final
oAuthProviders List<AuthProvider>
List of Auth Providers.
final
pingCount int
Number of times the ping was received for this project.
final
pingedAt String
Last ping datetime in ISO 8601 format.
final
platforms List
List of Platforms.
final
protocolStatusForGraphql bool
GraphQL protocol status
final
protocolStatusForRest bool
REST protocol status
final
protocolStatusForWebsocket bool
Websocket protocol status
final
region String
Project region
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceStatusForAccount bool
Account service status
final
serviceStatusForAvatars bool
Avatars service status
final
serviceStatusForDatabases bool
Databases (legacy) service status
final
serviceStatusForFunctions bool
Functions service status
final
serviceStatusForGraphql bool
GraphQL service status
final
serviceStatusForHealth bool
Health service status
final
serviceStatusForLocale bool
Locale service status
final
serviceStatusForMessaging bool
Messaging service status
final
serviceStatusForMigrations bool
Migrations service status
final
serviceStatusForProject bool
Project service status
final
serviceStatusForProxy bool
Proxy service status
final
serviceStatusForSites bool
Sites service status
final
serviceStatusForStorage bool
Storage service status
final
serviceStatusForTablesdb bool
TablesDB service status
final
serviceStatusForTeams bool
Teams service status
final
serviceStatusForUsers bool
Users service status
final
serviceStatusForVcs bool
VCS service status
final
smtpEnabled bool
Status for custom SMTP
final
smtpHost String
SMTP server host name
final
smtpPassword String
SMTP server password
final
smtpPort int
SMTP server port
final
smtpReplyTo String
SMTP reply to email
final
smtpSecure String
SMTP server secure protocol
final
smtpSenderEmail String
SMTP sender email
final
smtpSenderName String
SMTP sender name
final
smtpUsername String
SMTP server username
final
status String
Project status
final
teamId String
Project team ID.
final
url String
Project website URL.
final
webhooks List<Webhook>
List of Webhooks.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited