Report class
Report
- Implemented types
Constructors
-
Report({required String $id, required String $createdAt, required String $updatedAt, required String appId, required String type, required String title, required String summary, required String targetType, required String target, required List<
String> categories, required List<Insight> insights, String? analyzedAt}) -
Report.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
Report creation date in ISO 8601 format.
final
- $id → String
-
Report ID.
final
- $updatedAt → String
-
Report update date in ISO 8601 format.
final
- analyzedAt → String?
-
Time the report was analyzed in ISO 8601 format.
final
- appId → String
-
ID of the third-party app that submitted the report.
final
-
categories
→ List<
String> -
Categories covered by the report, e.g. performance, accessibility.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
insights
→ List<
Insight> -
Insights nested under this report.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String
-
Markdown summary describing the report.
final
- target → String
-
Free-form target identifier (URL for lighthouse, resource ID for db).
final
- targetType → String
-
Plural noun describing what the report analyzes, e.g. databases, sites, urls.
final
- title → String
-
Short, human-readable title for the report.
final
- type → String
-
Analyzer that produced this report. e.g. lighthouse, audit, databaseAnalyzer.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited