UsageEvent class
usageEvent
- Implemented types
Constructors
- UsageEvent({required String metric, required int value, required String time, required String path, required String method, required String status, required String resourceType, required String resourceId, required String countryCode, required String userAgent})
-
UsageEvent.fromMap(Map<
String, dynamic> map) -
factory
Properties
- countryCode → String
-
Country code in ISO 3166-1 two-character format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
The HTTP method.
final
- metric → String
-
The metric key.
final
- path → String
-
The API endpoint path.
final
- resourceId → String
-
The resource ID.
final
- resourceType → String
-
The resource type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
HTTP status code. Stored as string to preserve unset state (empty string = not available).
final
- time → String
-
The event timestamp.
final
- userAgent → String
-
The user agent string.
final
- value → int
-
The metric value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited