UsageGauge class

usageGauge

Implemented types

Constructors

UsageGauge({required String metric, required int value, required String time})
UsageGauge.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
metric String
The metric key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
The snapshot timestamp.
final
value int
The current snapshot value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited